// convert unix time to ISO 8601 format and print it to stdout.

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <getopt.h>

void usage(char *name)
{
    printf("%s: convert unix time to ISO 8601 format and print it to stdout\n"
    "Usage: %s [{-l|-u} {unix-time}] | [-h]\n"
    "\t-h          Print help\n"
    "\t-u          Print time in UTC\n"
    "\t-l          Print time in localtime\n", name, name);
}

int main(int argc, char **argv)
{
	char *progname = argv[0];
	time_t t;
	struct tm *tp;
	char buf[256];
	int opt;
	int utc;

	while ((opt = getopt(argc, argv, "l:u:h")) != EOF)
	{
		switch (opt)
		{
			case 'u':
				utc = 1;
				break;
			case 'l':
				utc = 0;
				break;
			case 'h':
				usage(progname);
				exit(0);
			default:
				fprintf(stderr, "unknown option: %c\n", opt);
				usage(progname);
				exit(1);
		}
	}
    if (argc > 2)
    {
		t = atoi(argv[2]);
		switch (utc)
		{
			case 1:
				tp = gmtime(&t);     // utc
				break;
			default:
				tp = localtime(&t);  // localtime
				break;
		}
		strftime(buf, sizeof(buf), "%Y-%m-%d %H:%M:%S", tp);
		puts(buf);
		return 0;
	}
	else
	{
		fprintf(stderr, "unknown option: %c\n", opt);
		usage(progname);
		exit(1);
	}
}
